@@ -72,7 +72,7 @@ sub start_httpd() {
 	exec './simple-httpd', $::pwd, "$::pwd/tmp", httpd_port();
 	exit 1;
     }
-    ('http://localhost:' . httpd_port(), $server_pid);
+    'http://localhost:' . httpd_port();
 }
 
 chdir 't' if -d 't';
