@@ -1,9 +1,7 @@
 package urpmi;
 
-use strict;
-
 # Dummy package for CPAN testers
 
-our $VERSION = '8.133.2';
+our $VERSION = '8.122';
 
 1;
